@@ -18,6 +18,7 @@ import xarray
 from rasterio import DatasetReader
 from rasterio.crs import CRS
 from rasterio.enums import Resampling
+from ruamel.yaml import CommentedMap
 from shapely.geometry.base import BaseGeometry
 
 import eodatasets3
@@ -301,6 +302,9 @@ class DatasetPrepare(Eo3Interface):
 
         self._dataset = dataset
 
+        #: The document that was written to disk, if any.
+        self.written_dataset_doc: Optional[CommentedMap] = None
+
         self._measurements = MeasurementBundler()
         self._accessories: Dict[str, Location] = {}
 
@@ -785,6 +789,7 @@ class DatasetPrepare(Eo3Interface):
             doc, metadata_path.parent, allow_paths_outside_base=False
         )
         serialise.dump_yaml(metadata_path, doc)
+        self.written_dataset_doc = doc
         return self._dataset.id, metadata_path
 
     def done(
